# Event ID 4742: A computer account was changed

## Description

This event generates every time a computer object is changed.

* This event generates only on domain controllers.
* You might see the same values for Subject\Security ID and Computer Account That Was Changed\Security ID in this event. This usually happens when you reboot a computer after adding it to the domain (the change takes effect after the reboot).
* For each change, a separate 4742 event will be generated.
* Some changes do not invoke a 4742 event, for example, changes made using Active Directory Users and Computers management console in Managed By tab in computer account properties.
* You might see this event without any changes inside, that is, where all Changed Attributes apear as “-“. This usually happens when a change is made to an attribute that is not listed in the event. In this case there is no way to determine which attribute was changed. For example, this would happen if you change the Description of a group object using the Active Directory Users and Computers administrative console. Also, if the discretionary access control list (DACL) is changed, a 4742 event will generate, but all attributes will be “-“.

Important: If you manually change any user-related setting or attribute, for example if you set the SMARTCARD_REQUIRED flag in userAccountControl for the computer account, then the sAMAccountType of the computer account will be changed to NORMAL_USER_ACCOUNT and you will get “4738: A user account was changed” instead of 4742 for this computer account. Essentially, the computer account will “become” a user account. For NORMAL_USER_ACCOUNT you will always get events from Audit User Account Management subcategory. We strongly recommend that you avoid changing any user-related settings manually for computer objects.

[MS Source](https://github.com/MicrosoftDocs/windows-itpro-docs/blob/master/windows/security/threat-protection/auditing/event-4742.md)

## Event Log Illustration & Event XML

[MS Source](https://github.com/MicrosoftDocs/windows-itpro-docs/blob/master/windows/security/threat-protection/auditing/event-4742.md)

## Data Dictionary

|	Standard Name	|	Field Name	|	Type	|	Description	|	Sample Value	|
|	----------------	|	----------------	|	----------------	|	----------------	|	----------------	|
|	computer_account_change	|	ComputerAccountChange	|	string	|		|	-	|
|	target_host_name	|	TargetUserName	|	string	|	the name of the computer account that was changed.	|	WIN81$	|
|	target_host_domain	|	TargetDomainName	|	string	|	domain name of changed computer account.	|	CONTOSO	|
|	target_host_sid	|	TargetSid	|	string	|	SID of changed computer account.	|	S-1-5-21-3457937927-2839227994-823803824-6116	|
|	user_sid	|	SubjectUserSid	|	string	|	SID of account that requested the “change Computer object” operation.	|	S-1-5-21-3457937927-2839227994-823803824-1104	|
|	user_name	|	SubjectUserName	|	string	|	the name of the account that requested the “change Computer object” operation.	|	dadmin	|
|	user_domain	|	SubjectDomainName	|	string	|	subject’s domain name.	|	CONTOSO	|
|	user_logon_id	|	SubjectLogonId	|	integer	|	hexadecimal value that can help you correlate this event with recent events that might contain the same Logon ID, for example, “4624: An account was successfully logged on.”	|	0x2e80c	|
|	user_privilege_list	|	PrivilegeList	|	string	|	the list of user privileges which were used during the operation, for example, SeBackupPrivilege. This parameter might not be captured in the event, and in that case appears as “-”.	|	-	|
|	target_host_sam_name	|	SamAccountName	|	string	|	logon name for account used to support clients and servers from previous versions of Windows (pre-Windows 2000 logon name). If the value of sAMAccountName attribute of computer object was changed, you will see the new value here.	|	WIN8$.	|
|	target_host_display_name	|	DisplayName	|	string	|	it is a name displayed in the address book for a particular account (typically – user account). This is usually the combination of the user's first name, middle initial, and last name. For computer objects, it is optional, and typically is not set. You can change this attribute by using Active Directory Users and Computers, or through a script, for example. If the value of displayName attribute of computer object was changed, you will see the new value here.	|	-	|
|	target_host_principal_name	|	UserPrincipalName	|	string	|	internet-style login name for the account, based on the Internet standard RFC 822. By convention this should map to the account's email name. If the value of userPrincipalNameattribute of computer object was changed, you will see the new value here. For computer objects, it is optional, and typically is not set. You can change this attribute by using Active Directory Users and Computers, or through a script, for example.	|	-	|
|	target_host_home_directory	|	HomeDirectory	|	string	|	user's home directory. If homeDrive attribute is set and specifies a drive letter, homeDirectory should be a UNC path. The path must be a network UNC of the form \\Server\Share\Directory. If the value of homeDirectory attribute of computer object was changed, you will see the new value here. For computer objects, it is optional, and typically is not set. You can change this attribute by using Active Directory Users and Computers, or through a script, for example.	|	-	|
|	target_host_home_oath	|	HomePath	|	string	|	specifies the drive letter to which to map the UNC path specified by homeDirectory account’s attribute. The drive letter must be specified in the form “DRIVE_LETTER:”. For example – “H:”. If the value of homeDrive attribute of computer object was changed, you will see the new value here. For computer objects, it is optional, and typically is not set. You can change this attribute by using Active Directory Users and Computers, or through a script, for example.	|	-	|
|	target_host_script_path	|	ScriptPath	|	string	|	specifies the path of the account’s logon script. If the value of scriptPathattribute of computer object was changed, you will see the new value here. For computer objects, it is optional, and typically is not set. You can change this attribute by using Active Directory Users and Computers, or through a script, for example.	|	-	|
|	target_host_profile_path	|	ProfilePath	|	string	|	specifies a path to the account's profile. This value can be a null string, a local absolute path, or a UNC path. If the value of profilePath attribute of computer object was changed, you will see the new value here. For computer objects, it is optional, and typically is not set. You can change this attribute by using Active Directory Users and Computers, or through a script, for example.	|	-	|
|	target_host_user_workstations	|	UserWorkstations	|	string	|	contains the list of NetBIOS or DNS names of the computers from which the user can logon. Each computer name is separated by a comma. The name of a computer is the sAMAccountName property of a computer object. If the value of userWorkstations attribute of computer object was changed, you will see the new value here. For computer objects, it is optional, and typically is not set. You can change this attribute by using Active Directory Users and Computers, or through a script, for example.	|	-	|
|	target_host_password_last_set	|	PasswordLastSet	|	date	|	last time the account’s password was modified. If the value of pwdLastSet attribute of computer object was changed, you will see the new value here. For example: 8/12/2015 11:41:39 AM. This value will be changed, for example, after manual computer account reset action or automatically every 30 days by default for computer objects.	|	-	|
|	target_host_account_expires	|	AccountExpires	|	date	|	the date when the account expires. If the value of accountExpiresattribute of computer object was changed, you will see the new value here. For computer objects, it is optional, and typically is not set. You can change this attribute by using Active Directory Users and Computers, or through a script, for example.	|	-	|
|	host_primary_group_id	|	PrimaryGroupId	|	integer	|	Relative Identifier (RID) of computer’s object primary group.	|	-	|
|	target_host_allowed_to_delegate	|	AllowedToDelegateTo	|	string	|	the list of SPNs to which this account can present delegated credentials. Can be changed using Active Directory Users and Computers management console in Delegation tab of computer account. If the SPNs list on Delegation tab of a computer account was changed, you will see the new SPNs list in AllowedToDelegateTo field (note that you will see the new list instead of changes) of this event.	|	%%1793	|
|	target_host_old_uac_value	|	OldUacValue	|	string	|	specifies flags that control password, lockout, disable/enable, script, and other behavior for the user or computer account. This parameter contains the previous value of userAccountControlattribute of computer object.	|	0x80	|
|	target_host_new_uac_value	|	NewUacValue	|	string	|	specifies flags that control password, lockout, disable/enable, script, and other behavior for the user or computer account. If the value of userAccountControl attribute of computer object was changed, you will see the new value here.	|	0x2080	|
|	target_host_account_control	|	UserAccountControl	|	string	|	shows the list of changes in userAccountControl attribute. You will see a line of text for each change. See possible values in here: “Table 7. User’s or Computer’s account UAC flags.”. In the “User Account Control field text” column, you can see text that will be displayed in the User Account Controlfield in 4742 event.	|	%%2093	|
|	target_host_parameters	|	UserParameters	|	string	|	if you change any setting using Active Directory Users and Computers management console in Dial-in tab of computer’s account properties, then you will see \<value changed, but not displayed\> in this field.	|	-	|
|	process_id	|	ProcessId	|	integer	|	Process ID used by the os to identify the created process (child)	|	4756	|
|	target_host_sid_history	|	SidHistory	|	string	|	contains previous SIDs used for the object if the object was moved from another domain. Whenever an object is moved from one domain to another, a new SID is created and becomes the objectSID. The previous SID is added to the sIDHistory property. If the value of sIDHistory attribute of computer object was changed, you will see the new value here.	|	-	|
|	target_host_logon_hours	|	LogonHours	|	string	|	hours that the account is allowed to logon to the domain. If the value of logonHours attribute of computer object was changed, you will see the new value here. For computer objects, it is optional, and typically is not set. You can change this attribute by using Active Directory Users and Computers, or through a script, for example.	|	-	|
|	target_host_dns_host_name	|	DnsHostName	|	string	|	name of computer account as registered in DNS. If the value of dNSHostName attribute of computer object was changed, you will see the new value here.	|	-	|
|	target_host_service_principal_names	|	ServicePrincipalNames	|	string	|	The list of SPNs, registered for computer account. If the SPN list of a computer account changed, you will see the new SPN list in Service Principal Names field (note that you will see the new list instead of changes).	|	-	|
